OC.L10N.register(
    "dav",
    {
    "Calendar" : "Egutegia",
    "Tasks" : "Zereginak",
    "Personal" : "Pertsonala",
    "{actor} created calendar {calendar}" : "{actor}-(e)k sortutako egutegia: {calendar}",
    "You created calendar {calendar}" : "{calendar} egutegia sortu duzu",
    "{actor} deleted calendar {calendar}" : "{actor}-(e)k {calendar} egutegia ezabatu du",
    "You deleted calendar {calendar}" : "{calendar} egutegia ezabatu duzu",
    "{actor} updated calendar {calendar}" : "{actor}-(e)k {calendar} egutegia eguneratu du",
    "You updated calendar {calendar}" : "{calendar} egutegia eguneratu duzu ",
    "{actor} restored calendar {calendar}" : "{actor}-(e)k {calendar} egutegia leheneratu du",
    "You restored calendar {calendar}" : "{calendar} egutegia leheneratu duzu",
    "You shared calendar {calendar} as public link" : " {calendar} partekatu duzu esteka publiko gisa",
    "You removed public link for calendar {calendar}" : "{calendar} egutegiaren esteka publikoa kendu duzu",
    "{actor} shared calendar {calendar} with you" : "{actor}-(e)k zurekin {calendar} egutegia partekatu du",
    "You shared calendar {calendar} with {user}" : "{calendar} egutegia {user} erabiltzailearekin partekatu duzu",
    "{actor} shared calendar {calendar} with {user}" : "{actor}-(e)k {calendar} egutegia {user}-(r)ekin partekatu du",
    "{actor} unshared calendar {calendar} from you" : "{actor}-(e)k zurekin {calendar} egutegia partekatzeari utzi dio",
    "You unshared calendar {calendar} from {user}" : "{calendar} egutegia {user}-(r)ekin partekatzeari utzi diozu ",
    "{actor} unshared calendar {calendar} from {user}" : "{actor}-(e)k {user} erabiltzailearekin {calendar} egutegia partekatzeari utzi dio",
    "{actor} unshared calendar {calendar} from themselves" : "{actor}-(e)k {calendar} egutegiaren partekatzea eten du beretzat.",
    "You shared calendar {calendar} with group {group}" : "{calendar} egutegia {group} taldearekin partekatu duzu",
    "{actor} shared calendar {calendar} with group {group}" : "{actor}-(e)k {group} taldearekin {calendar} egutegia partekatu du",
    "You unshared calendar {calendar} from group {group}" : "{group} taldearekin {calendar} egutegia partekatzeari utzi diozu.",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}-(e)k  {group} taldearekin {calendar} egutegia partekatzeari utzi dio.",
    "Untitled event" : "Izenik gabeko gertaera",
    "{actor} created event {event} in calendar {calendar}" : "{actor} erabiltzaileak {event} gertaera sortu du {calendar} egutegian.",
    "You created event {event} in calendar {calendar}" : "{calendar} egutegian {event} gertaera sortu duzu",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} erabiltzaileak {event} gertaera ezabatu du {calendar} egutegitik",
    "You deleted event {event} from calendar {calendar}" : "{event} gertaera ezabatu duzu {calendar} egutegitik ",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} erabiltzaileak {event} gertaera eguneratu du {calendar} egutegian",
    "You updated event {event} in calendar {calendar}" : "{event} gertaera eguneratu duzu {calendar} egutegian ",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} erabiltzaileak {event} gertaera {sourceCalendar} egutegitik {targetCalendar} egutegira mugitu du",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{event} gertaera {sourceCalendar} egutegitik {targetCalendar} egutegira mugitu duzu",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} erabiltzaileak {calendar} egutegiko {event} gertaera leheneratu du",
    "You restored event {event} of calendar {calendar}" : "{calendar} egutegiko {event} gertaera leheneratu duzu",
    "Busy" : "Lanpetua",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} erabiltzaileak {calendar} zerrendan {todo} egitekoa sortu du",
    "You created to-do {todo} in list {calendar}" : "{calendar} zerrendan {todo} egitekoa sortu duzu",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor}-(e)k {calendar} zerrendan {todo} egitekoa ezabatu du",
    "You deleted to-do {todo} from list {calendar}" : " {calendar} zerrendan {todo} egitekoa ezabatu duzu",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor}-(e)k {calendar} zerrendan {todo} egitekoa eguneratu du",
    "You updated to-do {todo} in list {calendar}" : "{calendar} zerrendan {todo} egitekoa eguneratu duzu",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor}-(e)k {calendar} zerrendan {todo} egitekoa burutu du.",
    "You solved to-do {todo} in list {calendar}" : " {calendar} zerrendan {todo} egitekoa burutu duzu",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor}-(e)k {calendar} zerrendan {todo} egitekoa berrireki du",
    "You reopened to-do {todo} in list {calendar}" : "{calendar} zerrendan {todo} egitekoa berrireki duzu",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor}-(e)k {todo} egitekoa {sourceCalendar} zerrendatik {targetCalendar} zerrendara mugitu du",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{todo} egitekoa {sourceCalendar} zerrendatik {targetCalendar} zerrendara mugitu duzu",
    "Calendar, contacts and tasks" : "Egutegia, kontaktuak eta zereginak",
    "A <strong>calendar</strong> was modified" : "<strong>Egutegi</strong> bat aldatu da",
    "A calendar <strong>event</strong> was modified" : "Egutegiaren <strong>gertaera</strong> bat aldatu da",
    "A calendar <strong>to-do</strong> was modified" : "Egutegi baten <strong>egiteko</strong> bat aldatu da",
    "Contact birthdays" : "Kontaktuen urtebetetzeak",
    "Death of %s" : "%s(r)en heriotza",
    "Untitled calendar" : "Izenik gabeko egutegia",
    "Calendar:" : "Egutegia:",
    "Date:" : "Data:",
    "Where:" : "Non:",
    "Description:" : "Deskribapena:",
    "_%n year_::_%n years_" : ["Urte %n","%n urte"],
    "_%n month_::_%n months_" : ["Hilabete %n","%n hilabete"],
    "_%n day_::_%n days_" : ["Egun %n","%n egun"],
    "_%n hour_::_%n hours_" : ["Ordu %n","%n ordu"],
    "_%n minute_::_%n minutes_" : ["Minutu %n","%n minutu"],
    "%s (in %s)" : "%s (%s(e)tik)",
    "%s (%s ago)" : "%s (orain dela %s)",
    "Calendar: %s" : "Egutegia: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Deskripzioa: %s",
    "Where: %s" : "Non: %s",
    "%1$s via %2$s" : "%2$s bidez, %1$s",
    "Cancelled: %1$s" : "Utzita: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" bertan behera utzi da",
    "Re: %1$s" : "Er: %1$s",
    "%1$s has accepted your invitation" : "%1$s zure gonbidapena onartu du",
    "%1$s has tentatively accepted your invitation" : "%1$s zure gonbidapena behin-behinean onartu du",
    "%1$s has declined your invitation" : "%1$s zure gonbidapenari uko egin dio",
    "%1$s has responded to your invitation" : "%1$s -(e)k zure gonbidapena erantzun du",
    "Invitation updated: %1$s" : "Gonbidapena eguneratuta: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s-k \"%2$s\" ekitaldia eguneratu du",
    "Invitation: %1$s" : "Gonbidapena: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s-k \"%2$s\"-ra gonbidatu nahi zaitu",
    "Organizer:" : "Antolatzailea:",
    "Attendees:" : "Parte-hartzaileak:",
    "Title:" : "Izenburua:",
    "Time:" : "Noiz:",
    "Location:" : "Kokapena:",
    "Link:" : "Esteka:",
    "Accept" : "Onartu",
    "Decline" : "Uko egin",
    "More options …" : "Aukera gehiago …",
    "More options at %s" : "Aukera gehiago hemen %s ",
    "Contacts" : "Kontaktuak",
    "{actor} created address book {addressbook}" : "{actor}-(e)k {addressbook} helbide-liburua sortu du ",
    "You created address book {addressbook}" : "{addressbook} helbide-liburua sortu duzu",
    "{actor} deleted address book {addressbook}" : "{actor}-(e)k {addressbook} helbide liburua ezabatu du",
    "You deleted address book {addressbook}" : "{addressbook} helbide-liburua ezabatu duzu",
    "{actor} updated address book {addressbook}" : "{actor}-(e)k {addressbook} helbide-liburua  eguneratu du",
    "You updated address book {addressbook}" : "{addressbook} helbide-liburua eguneratu duzu",
    "{actor} shared address book {addressbook} with you" : "{actor}-(e)k {addressbook} helbide-liburua  partekatu du",
    "You shared address book {addressbook} with {user}" : "{addressbook} helbide-liburua partekatu duzu",
    "{actor} shared address book {addressbook} with {user}" : "{actor}-(e)k {addressbook} helbide-liburua  partekatu du {user}-(r)ekin",
    "{actor} unshared address book {addressbook} from you" : "{actor}-(e)k {addressbook} helbide-liburua zurekin partekatzeari utzi dio",
    "You unshared address book {addressbook} from {user}" : "{addressbook} helbide-liburua {user}-(r)ekin partekatzeari utzi diozu",
    "{actor} unshared address book {addressbook} from {user}" : "{actor}-(e)k {addressbook} helbide-liburua {user}-(r)ekin partekatzeari utzi dio",
    "{actor} unshared address book {addressbook} from themselves" : "{actor}-(e)k {addressbook} helbide-liburuaren partekatzea eten du beretzat.",
    "You shared address book {addressbook} with group {group}" : "{addressbook} helbide-liburua partekatu duzu {group} taldearekin",
    "{actor} shared address book {addressbook} with group {group}" : "{actor}-(e)k {addressbook} helbide-liburua partekatu du {group} taldearekin",
    "You unshared address book {addressbook} from group {group}" : "{addressbook} helbide-liburua {group} taldearekin partekatzeari utzi diozu",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor}-(e)k {addressbook} helbide-liburua {group} taldearekin partekatzeari utzi dio",
    "{actor} created contact {card} in address book {addressbook}" : "{actor}-(e)k {card} kontaktua sortu du {addressbook} helbide-liburuan",
    "You created contact {card} in address book {addressbook}" : "{card} kontaktua sortu duzu {addressbook} helbide-liburuan",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor}-(e)k {card} kontaktua ezabatu du {addressbook} helbide-liburutik",
    "You deleted contact {card} from address book {addressbook}" : "{card} kontaktua ezabatu duzu {addressbook} helbide-liburutik",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor}-(e)k {card} kontaktua eguneratu du {addressbook} helbide-liburuan",
    "You updated contact {card} in address book {addressbook}" : "{card} kontaktua eguneratu duzu {addressbook} helbide-liburuan",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>kontaktu</strong> edo <strong>helbide-liburu</strong>bat aldatu da",
    "Accounts" : "Kontuak",
    "System address book which holds all accounts" : "Kontu guztiak dituen sistemaren helbide-liburua",
    "File is not updatable: %1$s" : "Fitxategia ez da eguneragarria: %1$s",
    "Could not write to final file, canceled by hook" : "Ezin izan da azken fitxategian idatzi, kakoak bertan behera utzi du",
    "Could not write file contents" : "Ezin izan dira fitxategiaren edukiak idatzi",
    "_%n byte_::_%n bytes_" : ["Byte %n","%n byte"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Errore bat gertatu da fitxategia helburuko kokapenera kopiatzean (kopiatua: %1$s, espero zen fitxategi-tamaina: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "%1$sfitxategi-tamaina espero zen baina irakurria (Nextcloud bezerotik) eta idatzia (Nextcloud biltegian) %2$sizan da. Bidaltzailearen aldean sareko arazo bat izan daiteke edo zerbitzariaren arazo bat biltegian idazteko.",
    "Could not rename part file to final file, canceled by hook" : "Ezin izan da zati-fitxategiaren izena aldatu azken fitxategira, kakoak bertan behera utzi du",
    "Could not rename part file to final file" : "Ezin izan da zati-fitxategia azken fitxategira aldatu",
    "Failed to check file size: %1$s" : "Ezin izan da egiaztatu fitxategiaren tamaina:%1$s",
    "Could not open file" : "Ezin izan da fitxategia ireki",
    "Encryption not ready: %1$s" : "Enkriptatzea ez dago prest:%1$s",
    "Failed to open file: %1$s" : "Ezin izan da fitxategia ireki:%1$s",
    "Failed to unlink: %1$s" : "Ezin izan da deskonektatu:%1$s",
    "Invalid chunk name" : "Zati izen baliogabea",
    "Could not rename part file assembled from chunks" : "Ezin izan da zati-fitxategiaren izena aldatu zenbait zatiz osatuta dagoelako",
    "Failed to write file contents: %1$s" : "Ezin izan dira fitxategiaren edukiak idatzi:%1$s",
    "File not found: %1$s" : "Ez da fitxategirik aurkitu:%1$s",
    "System is in maintenance mode." : "Sistema mantentze moduan dago.",
    "Upgrade needed" : "Bertsio-berritzea beharrezkoa",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Zure %s HTTPS erabiltzeko konfiguratu behar da CalDAV eta CardDAV erabiltzeko iOS eta macOSrekin.",
    "Configures a CalDAV account" : "CalDAV kontu bat konfiguratzen du",
    "Configures a CardDAV account" : "CardDAV kontu bat konfiguratzen du",
    "Events" : "Gertaerak",
    "Untitled task" : "Izenik gabeko zeregina",
    "Completed on %s" : "%s-an osatua",
    "Due on %s by %s" : "%s-(e)an epemuga %s-(e)k",
    "Due on %s" : "%s-(e)an epemuga",
    "DAV system address book" : "DAV sistemaren helbide-liburua",
    "No outstanding DAV system address book sync." : "Ez dago DAV sistema helbide-liburuaren sinkronizazio arrarorik.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV sistemaren helbide-liburuaren sinkronizazioa oraindik ez da martxan jarri zure instantziak 1000 erabiltzaile baino gehiago dituelako edo akats bat gertatu delako. Mesedez, exekutatu eskuz \"occ dav:sync-system-addressbook\" deituz.",
    "Migrated calendar (%1$s)" : "Migratutako egutegia (%1$s)",
    "Calendars including events, details and attendees" : "Egutegiak, gertaerak, xehetasunak eta parte-hartzaileak barne",
    "Contacts and groups" : "Kontaktuak eta taldeak",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV amaiera-puntua",
    "First day" : "Lehen eguna",
    "Last day (inclusive)" : "Azken eguna (barne)",
    "Short absence status" : "Absentzia-egoera laburra",
    "Long absence Message" : "Absentzia-mezu luzea",
    "Save" : "Gorde",
    "Disable absence" : "Desgaitu absentzia",
    "Absence saved" : "Absentzia gordeta",
    "Failed to save your absence settings" : "Ezin izan dira zure absentzia ezarpenak gorde",
    "Absence cleared" : "Abszentzia ezabatuta",
    "Time zone:" : "Ordu-zona:",
    "to" : "honi",
    "Delete slot" : "Ezabatu tartea",
    "No working hours set" : "Ez dira laneko orduak ezarri",
    "Add slot" : "Gehitu tartea",
    "Monday" : "Astelehena",
    "Tuesday" : "Asteartea",
    "Wednesday" : "Asteazkena",
    "Thursday" : "Osteguna",
    "Friday" : "Ostirala",
    "Saturday" : "Larunbata",
    "Sunday" : "Igandea",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Eskuragarri ez egotean, ezarri automatikoki erabiltzailearen egoera \"Ez molestatu\" moduan jakinarazpen guztiak isilarazteko.",
    "Failed to load availability" : "Ezin izan da eskuragarritasuna kargatu",
    "Saved availability" : "Eskuragarritasuna gorde da",
    "Failed to save availability" : "Ezin izan da eskuragarritasuna gorde",
    "Availability" : "Eskuragarritasuna",
    "Calendar server" : "Egutegi-zerbitzaria",
    "Send invitations to attendees" : "Parte-hartzaileei gonbidapenak bidali",
    "Automatically generate a birthday calendar" : "Automatikoki sortu urtebetetzeen egutegia",
    "Birthday calendars will be generated by a background job." : "Urtebetetze egutegiak atzealdeko lan batek sortuko ditu.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Beraz ez dira gaitu bezain laster prest egongo, baina denbora bat pasatzean agertuko dira.",
    "Send notifications for events" : "Bidali jakinarazpenak gertaerentzako",
    "Notifications are sent via background jobs, so these must occur often enough." : "Jakinarazpenak atzealdeko lanen bidez bidaliko dira, beraz sarri gertatu behar dira.",
    "Send reminder notifications to calendar sharees as well" : "Bidali abisuaren jakinarazpenak egutegi partekatzea dutenei ere",
    "Reminders are always sent to organizers and attendees." : "Abisuak beti bidaltzen zaizkie antolatzaileei eta parrte-hartzaileei.",
    "Enable notifications for events via push" : "Gaitu push bidezko jakinarazpenak gertaerentzat",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instalatu ezazu {calendarappstoreopen}Egutegi aplikazioa{linkclose} ere, edo {calendardocopen}konektatu zure ordenagailua eta mugikorra sinkronizatzeko ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Egiaztatu {emailopen}posta elektroniko zerbitzaria{linkclose} ondo konfiguratuta dagoela.",
    "There was an error updating your attendance status." : "Errore bat gertatu da zure parte-hartze egoera eguneratzerakoan.",
    "Please contact the organizer directly." : "Mesedez jarri harremanetan antolatzailearekin zuzenean.",
    "Are you accepting the invitation?" : "Gonbidapena onartzen duzu?",
    "Tentative" : "Behin behinekoa",
    "Your attendance was updated successfully." : "Zure parte-hartzea ondo eguneratu da.",
    "To-dos" : "Egitekoak",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Zure lan orduak konfiguratzen badituzu, beste erabiltzaileek bulegotik kanpo zaudela ikusiko dute bilera bat erreserbatzen dutenean."
},
"nplurals=2; plural=(n != 1);");
